summaryrefslogtreecommitdiffstats
path: root/video/mp_image.h
diff options
context:
space:
mode:
Diffstat (limited to 'video/mp_image.h')
-rw-r--r--video/mp_image.h14
1 files changed, 4 insertions, 10 deletions
diff --git a/video/mp_image.h b/video/mp_image.h
index 1e2933170a..c378a01b78 100644
--- a/video/mp_image.h
+++ b/video/mp_image.h
@@ -72,9 +72,11 @@ struct mp_image_params {
*/
typedef struct mp_image {
unsigned int flags; // same as fmt.flags
- struct mp_imgfmt_desc fmt;
- // fields redundant to fmt, for convenience or compatibility
+ struct mp_image_params params;
+
+ // fields redundant to params.imgfmt, for convenience or compatibility
+ struct mp_imgfmt_desc fmt;
enum mp_imgfmt imgfmt;
int num_planes;
int chroma_x_shift; // horizontal
@@ -97,10 +99,6 @@ typedef struct mp_image {
int plane_w[MP_MAX_PLANES];
int plane_h[MP_MAX_PLANES];
- enum mp_csp colorspace;
- enum mp_csp_levels levels;
- enum mp_chroma_location chroma_location;
-
/* only inside filter chain */
double pts;
/* memory management */
@@ -139,10 +137,6 @@ struct mp_image *mp_image_new_external_ref(struct mp_image *img, void *arg,
bool (*is_unique)(void *arg),
void (*free)(void *arg));
-struct mp_csp_details;
-void mp_image_set_colorspace_details(struct mp_image *image,
- struct mp_csp_details *csp);
-
void mp_image_params_guess_csp(struct mp_image_params *params);
bool mp_image_params_equals(const struct mp_image_params *p1,